@@ -1,16 +1,22 @@
 recTensor <- function(S = NULL, A = NULL, idx = 1:3, reverse = FALSE){
     if (is(S)[1] == "Tensor") {
         X_bar <- S
+        if(length(dim(S)) > 3){
+            idx <- seq_along(A)
+        }
     }
     else if ("numeric" %in% is(S) && length(S) == 1) {
-        X_bar <- rand_tensor(c(1, 1, 1))
+        X_bar <- rand_tensor(rep(1, length=length(idx)))
         X_bar@data[] <- S
     }
     else if ("numeric" %in% is(S) && length(S) != 1) {
         X_bar <- rand_tensor(sapply(A, nrow))
         X_bar@data[] <- 0
-        for (x in 1:length(A)) {
-            X_bar@data[x, x, x] <- S[x]
+        for (n in seq_along(S)) {
+            cmd = paste0("X_bar@data[",
+                paste(rep("n", length=length(A)), collapse=","),
+                "] <- S[n]")
+            eval(parse(text=cmd))
         }
     }
     if (!reverse) {
