@@ -12,6 +12,11 @@ out6 <- NMF(X, M=M, J=3, algorithm="Neyman", num.iter=2)
 out7 <- NMF(X, M=M, J=3, algorithm="Alpha", num.iter=2)
 out8 <- NMF(X, M=M, J=3, algorithm="Beta", num.iter=2)
 out9 <- NMF(X, M=M, J=3, algorithm="PGD", num.iter=2)
+out10 <- NMF(X, M=M, J=3, algorithm="Projected", num.iter=2)
+out11 <- NMF(X, M=M, J=3, algorithm="NHR", num.iter=2)
+out12 <- NMF(X, M=M, J=3, algorithm="DTPP", num.iter=2)
+out13 <- NMF(X, M=M, J=3, algorithm="Orthogonal", num.iter=2)
+out14 <- NMF(X, M=M, J=3, algorithm="OrthReg", num.iter=2)
 
 expect_equivalent(length(out1), 10)
 expect_equivalent(length(out2), 10)
@@ -22,3 +27,8 @@ expect_equivalent(length(out6), 10)
 expect_equivalent(length(out7), 10)
 expect_equivalent(length(out8), 10)
 expect_equivalent(length(out9), 10)
+expect_equivalent(length(out10), 10)
+expect_equivalent(length(out11), 10)
+expect_equivalent(length(out12), 10)
+expect_equivalent(length(out13), 10)
+expect_equivalent(length(out14), 10)
